# Generated by Django 4.2.11 on 2024-03-25 12:18

from django.db import migrations, models
import django.db.models.deletion
import huscy.data_acquisition_methods.questionaire.models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('project_design', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Questionaire',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, verbose_name='Name')),
                ('filehandle', models.FileField(upload_to=huscy.data_acquisition_methods.questionaire.models.get_upload_path, verbose_name='Filehandle')),
                ('uploaded_at', models.DateTimeField(auto_now_add=True)),
                ('uploaded_by', models.CharField(editable=False, max_length=255)),
                ('data_acquisition_method', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='project_design.dataacquisitionmethod')),
            ],
        ),
    ]
